<?php

namespace CBCurrencyConverterElemWidget\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * class CBCurrencyConverter_ElemWidget
 */
class CBCurrencyConverter_ElemWidget extends \Elementor\Widget_Base {

	/**
	 * Retrieve google maps widget name.
	 *
	 * @return string Widget name.
	 * @since  1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'cbcurrencyconverter';
	}

	/**
	 * Retrieve google maps widget title.
	 *
	 * @return string Widget title.
	 * @since  1.0.0
	 * @access public
	 *
	 */
	public function get_title() {
		return esc_html__( 'CBX Currency Converter', 'cbcurrencyconverter' );
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since  1.0.10
	 * @access public
	 *
	 */
	public function get_categories() {
		return array( 'codeboxr' );
	}

	/**
	 * Retrieve google maps widget icon.
	 *
	 * @return string Widget icon.
	 * @since  1.0.0
	 * @access public
	 *
	 */
	public function get_icon() {
		return 'cbcurrencyconverter-icon';
	}

	/**
	 * Register google maps widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$setting_global = get_option( 'cbcurrencyconverter_global_settings' );
		$setting_list   = get_option( 'cbcurrencyconverter_list_settings' );
		$setting_cal    = get_option( 'cbcurrencyconverter_calculator_settings' );

		//get default values from global settings

		//general setting
		$layout       = ( isset( $setting_global['cbcurrencyconverter_defaultlayout'] ) ) ? sanitize_text_field( $setting_global['cbcurrencyconverter_defaultlayout'] ) : 'cal';
		$decimalpoint = ( isset( $setting_global['cbcurrencyconverter_decimalpoint'] ) ) ? intval( $setting_global['cbcurrencyconverter_decimalpoint'] ) : 2;

		//calculator setting
		$calc_currencies     = ( isset( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? wp_unslash( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) : array( 'USD' );
		$calc_currencies_to  = ( isset( $setting_cal['cbcurrencyconverter_enabled_currencies_calculator_to'] ) ) ? wp_unslash( $setting_cal['cbcurrencyconverter_enabled_currencies_calculator_to'] ) : array( 'GBP', 'CAD', 'AUD' );
		$calc_from_currency  = ( isset( $setting_cal['cbcurrencyconverter_fromcurrency'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_fromcurrency'] ) : 'USD';
		$calc_to_currency    = ( isset( $setting_cal['cbcurrencyconverter_tocurrency'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_tocurrency'] ) : 'CAD';
		$calc_default_amount = ( isset( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? floatval( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) : 1;
		$calc_title          = ( isset( $setting_cal['cbcurrencyconverter_title_cal'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_title_cal'] ) : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );

		//list setting
		$list_from_currency  = ( isset( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) ) ? sanitize_text_field( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) : 'USD';                               //we need to set something as default currency to make the list work
		$list_to_currency    = ( isset( $setting_list['cbcurrencyconverter_tocurrency_list'] ) ) ? wp_unslash( $setting_list['cbcurrencyconverter_tocurrency_list'] ) : array( 'GBP', 'CAD', 'AUD' );                           //list of currency
		$list_default_amount = ( isset( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) ) ? floatval( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) : 1;                                            //default amount
		$list_title          = ( isset( $setting_list['cbcurrencyconverter_title_list'] ) ) ? sanitize_text_field( $setting_list['cbcurrencyconverter_title_list'] ) : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title


		$this->start_controls_section(
			'section_cbcurrencyconverter_single',
			array(
				'label' => esc_html__( 'CBX Currency Converter Setting', 'cbcurrencyconverter' ),
			)
		);


		$this->add_control(
			'cbcurrencyconverter_layout',
			array(
				'label'       => esc_html__( 'Layout', 'cbcurrencyconverter' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'placeholder' => esc_html__( 'Select layout', 'cbcurrencyconverter' ),
				'default'     => $layout,
				'options'     => \CBCurrencyConverterHelper::get_layouts(),
				'label_block' => true,
			)
		);

		$this->add_control(
			'cbcurrencyconverter_decimalpoint',
			array(
				'label'   => esc_html__( 'Decimal Point', 'cbcurrencyconverter' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => $decimalpoint,
			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'section_cbcurrencyconverter_cal_settings',
			array(
				'label' => esc_html__( 'Calculator settings', 'cbcurrencyconverter' ),
			)
		);

		$this->add_control(
			'cbcurrencyconverter_calc_title',
			array(
				'label'   => esc_html__( 'Calculator Header', 'cbcurrencyconverter' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => $calc_title,
			)
		);

		$all_currencies = \CBCurrencyConverterHelper::getCurrencyList();

		$this->add_control(
			'cbcurrencyconverter_calc_currencies',
			array(
				'label'       => esc_html__( 'From Enable Currencies', 'cbcurrencyconverter' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'placeholder' => esc_html__( 'Select currencies from', 'cbcurrencyconverter' ),
				'default'     => array( 'USD' ),
				'options'     => $all_currencies,
				'multiple'    => true,
				'label_block' => true,
			)
		);

		$this->add_control(
			'cbcurrencyconverter_calc_currencies_to',
			array(
				'label'       => esc_html__( 'To Enable Currencies', 'cbcurrencyconverter' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'placeholder' => esc_html__( 'Select to currencies', 'cbcurrencyconverter' ),
				'default'     => array( 'GBP', 'CAD', 'AUD' ),
				'options'     => $all_currencies,
				'multiple'    => true,
				'label_block' => true,
			)
		);

		$this->add_control(
			'cbcurrencyconverter_calc_from_currency',
			array(
				'label'       => esc_html__( 'Calculator From Currency', 'cbcurrencyconverter' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'placeholder' => esc_html__( 'Select currency', 'cbcurrencyconverter' ),
				'default'     => $calc_from_currency,
				'options'     => $all_currencies,
				'label_block' => true,
			)
		);

		$this->add_control(
			'cbcurrencyconverter_calc_to_currency',
			array(
				'label'       => esc_html__( 'Calculator To Currency', 'cbcurrencyconverter' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'placeholder' => esc_html__( 'Select currency', 'cbcurrencyconverter' ),
				'default'     => $calc_to_currency,
				'options'     => $all_currencies,
				'label_block' => true,
			)
		);

		$this->add_control(
			'cbcurrencyconverter_calc_default_amount',
			array(
				'label'   => esc_html__( 'Default Amount for Calculator', 'cbcurrencyconverter' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'default' => $calc_default_amount,
			)
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'section_cbcurrencyconverter_list_settings',
			array(
				'label' => esc_html__( 'List settings', 'cbcurrencyconverter' ),
			)
		);
		$this->add_control(
			'cbcurrencyconverter_list_title',
			array(
				'label'   => esc_html__( 'List Header', 'cbcurrencyconverter' ),
				'type'    => \Elementor\Controls_Manager::TEXT,
				'default' => $list_title,
			)
		);

		$all_currencies = \CBCurrencyConverterHelper::getCurrencyList();

		$this->add_control(
			'cbcurrencyconverter_list_from_currency',
			array(
				'label'       => esc_html__( 'List From Currency', 'cbcurrencyconverter' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'placeholder' => esc_html__( 'Select currency', 'cbcurrencyconverter' ),
				'default'     => $list_from_currency,
				'options'     => $all_currencies,
				'label_block' => true,
			)
		);
		$this->add_control(
			'cbcurrencyconverter_list_to_currency',
			array(
				'label'       => esc_html__( 'List To Currencies', 'cbcurrencyconverter' ),
				'type'        => \Elementor\Controls_Manager::SELECT2,
				'placeholder' => esc_html__( 'Select currencies', 'cbcurrencyconverter' ),
				'default'     => $list_to_currency,
				'options'     => $all_currencies,
				'label_block' => true,
				'multiple'    => true,
			)
		);

		$this->add_control(
			'cbcurrencyconverter_list_default_amount',
			array(
				'label'   => esc_html__( 'Default Amount for List', 'cbcurrencyconverter' ),
				'type'    => \Elementor\Controls_Manager::NUMBER,
				'default' => $list_default_amount,
			)
		);

		$this->end_controls_section();
	}//end register_controls

	/**
	 * Render google maps widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {

		$setting_global = get_option( 'cbcurrencyconverter_global_settings' );
		$setting_list   = get_option( 'cbcurrencyconverter_list_settings' );
		$setting_cal    = get_option( 'cbcurrencyconverter_calculator_settings' );

		//get default values from global settings

		//general setting
		$layout       = ( isset( $setting_global['cbcurrencyconverter_defaultlayout'] ) ) ? sanitize_text_field( $setting_global['cbcurrencyconverter_defaultlayout'] ) : 'cal';
		$decimalpoint = ( isset( $setting_global['cbcurrencyconverter_decimalpoint'] ) ) ? intval( $setting_global['cbcurrencyconverter_decimalpoint'] ) : 2;

		//calculator setting
		$calc_currencies    = ( isset( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? wp_unslash( $setting_cal['cbcurrencyconverter_enabledcurrencies_calculator'] ) : [ 'USD' ];
		$calc_from_currency = ( isset( $setting_cal['cbcurrencyconverter_fromcurrency'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_fromcurrency'] ) : 'USD';


		$calc_currencies_to = ( isset( $setting_cal['cbcurrencyconverter_enabled_currencies_calculator_to'] ) ) ? wp_unslash( $setting_cal['cbcurrencyconverter_enabled_currencies_calculator_to'] ) : [ 'GBP', 'CAD', 'AUD' ];
		$calc_to_currency   = ( isset( $setting_cal['cbcurrencyconverter_tocurrency'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_tocurrency'] ) : 'CAD';

		$calc_default_amount = ( isset( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? floatval( $setting_cal['cbcurrencyconverter_defaultamount_for_calculator'] ) : 1;
		$calc_title          = ( isset( $setting_cal['cbcurrencyconverter_title_cal'] ) ) ? sanitize_text_field( $setting_cal['cbcurrencyconverter_title_cal'] ) : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );

		//list setting
		$list_from_currency  = ( isset( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) ) ? sanitize_text_field( $setting_list['cbcurrencyconverter_defaultcurrency_list'] ) : 'USD';                               //we need to set something as default currency to make the list work
		$list_to_currency    = ( isset( $setting_list['cbcurrencyconverter_tocurrency_list'] ) ) ? wp_unslash( $setting_list['cbcurrencyconverter_tocurrency_list'] ) : [ 'GBP', 'CAD', 'AUD' ];                                //list of currency
		$list_default_amount = ( isset( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) ) ? floatval( $setting_list['cbcurrencyconverter_defaultamount_forlist'] ) : 1;                                            //default amount
		$list_title          = ( isset( $setting_list['cbcurrencyconverter_title_list'] ) ) ? sanitize_text_field( $setting_list['cbcurrencyconverter_title_list'] ) : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title

		if ( ! is_array( $calc_currencies ) ) {
			$calc_currencies = [];
		}
		if ( ! is_array( $calc_currencies_to ) ) {
			$calc_currencies_to = [];
		}
		if ( ! is_array( $list_to_currency ) ) {
			$list_to_currency = [];
		}


		$calc_currencies    = array_values( array_filter( $calc_currencies ) );
		$calc_currencies_to = array_values( array_filter( $calc_currencies_to ) );
		$list_to_currency   = array_values( array_filter( $list_to_currency ) );


		$atts = array();

		$instance = $this->get_settings();

		$atts['layout']       = isset( $instance['cbcurrencyconverter_layout'] ) ? sanitize_text_field( $instance['cbcurrencyconverter_layout'] ) : $layout;
		$atts['decimalpoint'] = isset( $instance['cbcurrencyconverter_decimalpoint'] ) ? intval( $instance['cbcurrencyconverter_decimalpoint'] ) : $decimalpoint;


		//calculator setting
		$atts['calc_title']           = isset( $instance['cbcurrencyconverter_calc_title'] ) ? sanitize_text_field( $instance['cbcurrencyconverter_calc_title'] ) : $calc_title;
		$atts['calc_from_currencies'] = isset( $instance['cbcurrencyconverter_calc_currencies'] ) ? wp_unslash( $instance['cbcurrencyconverter_calc_currencies'] ) : $calc_currencies;
		$atts['calc_to_currencies']   = isset( $instance['cbcurrencyconverter_calc_currencies_to'] ) ? wp_unslash( $instance['cbcurrencyconverter_calc_currencies_to'] ) : $calc_currencies_to;

		$atts['calc_from_currency']  = isset( $instance['cbcurrencyconverter_calc_from_currency'] ) ? sanitize_text_field( $instance['cbcurrencyconverter_calc_from_currency'] ) : $calc_from_currency;
		$atts['calc_to_currency']    = isset( $instance['cbcurrencyconverter_calc_to_currency'] ) ? sanitize_text_field( $instance['cbcurrencyconverter_calc_to_currency'] ) : $calc_to_currency;
		$atts['calc_default_amount'] = isset( $instance['cbcurrencyconverter_calc_default_amount'] ) ? floatval( $instance['cbcurrencyconverter_calc_default_amount'] ) : $calc_default_amount;


		//list setting
		$atts['list_title']          = isset( $instance['cbcurrencyconverter_list_title'] ) ? sanitize_text_field( $instance['cbcurrencyconverter_list_title'] ) : $list_title;
		$atts['list_from_currency']  = isset( $instance['cbcurrencyconverter_list_from_currency'] ) ? sanitize_text_field( $instance['cbcurrencyconverter_list_from_currency'] ) : $list_from_currency;
		$atts['list_to_currency']    = isset( $instance['cbcurrencyconverter_list_to_currency'] ) ? wp_unslash( $instance['cbcurrencyconverter_list_to_currency'] ) : $list_to_currency;
		$atts['list_default_amount'] = isset( $instance['cbcurrencyconverter_list_default_amount'] ) ? floatval( $instance['cbcurrencyconverter_list_default_amount'] ) : $list_default_amount;


		$atts['calc_from_currencies'] = implode( ',', $atts['calc_from_currencies'] );
		$atts['calc_to_currencies']   = implode( ',', $atts['calc_to_currencies'] );
		$atts['list_to_currency']     = implode( ',', $atts['list_to_currency'] );

		$attr_html = '';

		foreach ( $atts as $key => $value ) {
			$attr_html .= ' ' . $key . '="' . $value . '" ';
		}

		echo do_shortcode( '[cbcurrencyconverter ' . $attr_html . ']' );

	}//end render

	/**
	 * Render google maps widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function content_template() {
		//
	}//end content_template
}//end CBCurrencyConverter_ElemWidget
